@@ -1,12 +1,5 @@
-from pythautomata.base_types.state import State
 from pythautomata.base_types.alphabet import Alphabet
-from functools import reduce
 from pythautomata.automata.deterministic_finite_automaton import DeterministicFiniteAutomaton as DFA
-from pythautomata.exceptions.non_deterministic_states_exception import NonDeterministicStatesException
-from random import seed, getrandbits, choice
-from pythautomata.model_exporters.encoded_file_exporting_strategy import EncodedFileExportingStrategy
-from pythautomata.model_exporters.image_exporting_strategy import ImageExportingStrategy
-from pythautomata.model_comparators.dfa_comparison_strategy import DFAComparisonStrategy as AutomataComparator
 import pythautomata.utilities.simple_dfa_generator as simple_dfa_generator
 import math
 from scipy.special import lambertw
@@ -28,6 +21,7 @@ def generate_dfa(alphabet: Alphabet, nominal_size: int, seed: int = 42) -> DFA:
     """
     k = len(alphabet)
     ro_k = k + lambertw(-k * exp(-k))
+    ro_k = ro_k.real
     v_k = ro_k/k
     number_of_states = math.ceil(nominal_size / v_k)
     dfa = simple_dfa_generator.generate_dfa(alphabet, number_of_states, seed)
